@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2023 Advanced Micro Devices, Inc. All rights reserved.
+// Copyright (c) 2017-2025 Advanced Micro Devices, Inc. All rights reserved.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -56,22 +56,51 @@
     #endif
 
     #ifndef DOXYGEN_DOCUMENTATION_BUILD
-        // Currently HIP on Windows has a bug involving inline device functions generating
-        // local memory/register allocation errors during compilation.  Current workaround is to
-        // use __attribute__((always_inline)) for the affected functions
-        #ifdef _WIN32
-            #define ROCPRIM_INLINE inline __attribute__((always_inline))
-        #else
-            #define ROCPRIM_INLINE inline
-        #endif
+        #define ROCPRIM_INLINE inline
+        #define ROCPRIM_LAUNCH_BOUNDS(...) __launch_bounds__(__VA_ARGS__)
     #else
         // Prefer simpler signatures to let Sphinx/Breathe parse them
         #define ROCPRIM_FORCE_INLINE inline
         #define ROCPRIM_INLINE inline
+        // Ignore __launch_bounds__ for doxygen builds
+        #define ROCPRIM_LAUNCH_BOUNDS(...)
     #endif
     #define ROCPRIM_FORCE_INLINE __attribute__((always_inline))
 #endif
 
+#undef ROCPRIM_TARGET_GCN3
+#undef ROCPRIM_TARGET_GCN5
+#undef ROCPRIM_TARGET_RDNA1
+#undef ROCPRIM_TARGET_RDNA2
+#undef ROCPRIM_TARGET_RDNA3
+#undef ROCPRIM_TARGET_RDNA4
+#undef ROCPRIM_TARGET_CDNA1
+#undef ROCPRIM_TARGET_CDNA2
+#undef ROCPRIM_TARGET_CDNA3
+
+// See https://llvm.org/docs/AMDGPUUsage.html#instructions
+#if defined(__gfx940__) || defined(__gfx941__) || defined(__gfx942__)
+    #define ROCPRIM_TARGET_CDNA3 1
+#elif defined(__gfx90a__)
+    #define ROCPRIM_TARGET_CDNA2 1
+#elif defined(__gfx908__)
+    #define ROCPRIM_TARGET_CDNA1 1
+#elif defined(__gfx900__) || defined(__gfx902__) || defined(__gfx904__) || defined(__gfx906__) \
+    || defined(__gfx90c__)
+    #define ROCPRIM_TARGET_GCN5 1
+#elif defined(__GFX12__)
+    #define ROCPRIM_TARGET_RDNA4 1
+#elif defined(__GFX11__)
+    #define ROCPRIM_TARGET_RDNA3 1
+#elif defined(__gfx1030__) || defined(__gfx1031__) || defined(__gfx1032__) || defined(__gfx1033__) \
+    || defined(__gfx1034__) || defined(__gfx1035__) || defined(__gfx1036__)
+    #define ROCPRIM_TARGET_RDNA2 1
+#elif defined(__gfx1010__) || defined(__gfx1011__) || defined(__gfx1012__) || defined(__gfx1013__)
+    #define ROCPRIM_TARGET_RDNA1 1
+#elif defined(__GFX8__)
+    #define ROCPRIM_TARGET_GCN3 1
+#endif
+
 // DPP is supported only after Volcanic Islands (GFX8+)
 // Only defined when support is present, in contrast to ROCPRIM_DETAIL_USE_DPP, which should be
 // always defined
@@ -90,6 +119,10 @@
     #define ROCPRIM_DETAIL_HAS_DPP_BROADCAST 1
 #endif
 
+#if defined(ROCPRIM_DETAIL_HAS_DPP) && (defined(__GFX8__) || defined(__GFX9__))
+    #define ROCPRIM_DETAIL_HAS_DPP_WF 1
+#endif
+
 #ifndef ROCPRIM_THREAD_LOAD_USE_CACHE_MODIFIERS
     #define ROCPRIM_THREAD_LOAD_USE_CACHE_MODIFIERS 1
 #endif
@@ -110,7 +143,8 @@
 #endif
 
 #ifndef ROCPRIM_NAVI
-    #if defined(__HIP_DEVICE_COMPILE__) && (defined(__GFX10__) || defined(__GFX11__))
+    #if defined(__HIP_DEVICE_COMPILE__) \
+        && (defined(__GFX10__) || defined(__GFX11__) || defined(__GFX12__))
         #define ROCPRIM_NAVI 1
     #else
         #define ROCPRIM_NAVI 0
@@ -123,22 +157,22 @@
 #define ROCPRIM_WARP_SIZE_64 64u
 #define ROCPRIM_MAX_WARP_SIZE ROCPRIM_WARP_SIZE_64
 
-#if (defined(_MSC_VER) && !defined(__clang__)) || (defined(__GNUC__) && !defined(__clang__))
-#define ROCPRIM_UNROLL
-#define ROCPRIM_NO_UNROLL
+#if(defined(_MSC_VER) && !defined(__clang__)) || (defined(__GNUC__) && !defined(__clang__))
+    #define ROCPRIM_UNROLL
+    #define ROCPRIM_NO_UNROLL
 #else
-#define ROCPRIM_UNROLL _Pragma("unroll")
-#define ROCPRIM_NO_UNROLL _Pragma("nounroll")
+    #define ROCPRIM_UNROLL _Pragma("unroll")
+    #define ROCPRIM_NO_UNROLL _Pragma("nounroll")
 #endif
 
 #ifndef ROCPRIM_GRID_SIZE_LIMIT
-#define ROCPRIM_GRID_SIZE_LIMIT std::numeric_limits<unsigned int>::max()
+    #define ROCPRIM_GRID_SIZE_LIMIT std::numeric_limits<unsigned int>::max()
 #endif
 
 #if __cpp_if_constexpr >= 201606
-#define ROCPRIM_IF_CONSTEXPR constexpr
+    #define ROCPRIM_IF_CONSTEXPR constexpr
 #else
-#define ROCPRIM_IF_CONSTEXPR
+    #define ROCPRIM_IF_CONSTEXPR
 #endif
 
 //  Copyright 2001 John Maddock.
@@ -181,4 +215,46 @@
     #define ROCPRIM_DETAIL_DEVICE_STATIC_ASSERT(expression, message)
 #endif
 
+/// \brief Clang predefined macro for device code on AMD GPU targets, either 32 or 64.
+///   It is undefined behavior to use this macro in host code when compiling with Clang.
+#ifndef __AMDGCN_WAVEFRONT_SIZE
+    #define __AMDGCN_WAVEFRONT_SIZE 64
+#endif
+
+/// \brief Wavefront size, either 32 or 64. May be defined by compiler flags when compiling
+///   with Clang if the value is equal to the wavefront size of all AMD GPU architectures
+///   currently being compiled for.
+///
+///   Only defined in device code unless defined by compiler flags as described above.
+#ifndef ROCPRIM_WAVEFRONT_SIZE
+    #define ROCPRIM_WAVEFRONT_SIZE __AMDGCN_WAVEFRONT_SIZE
+#endif
+
+// Helper macros to disable warnings in clang
+#ifdef __clang__
+    #define ROCPRIM_PRAGMA_TO_STR(x) _Pragma(#x)
+    #define ROCPRIM_CLANG_SUPPRESS_WARNING_PUSH _Pragma("clang diagnostic push")
+    #define ROCPRIM_CLANG_SUPPRESS_WARNING(w) ROCPRIM_PRAGMA_TO_STR(clang diagnostic ignored w)
+    #define ROCPRIM_CLANG_SUPPRESS_WARNING_POP _Pragma("clang diagnostic pop")
+    #define ROCPRIM_CLANG_SUPPRESS_WARNING_WITH_PUSH(w) \
+        ROCPRIM_CLANG_SUPPRESS_WARNING_PUSH ROCPRIM_CLANG_SUPPRESS_WARNING(w)
+#else // __clang__
+    #define ROCPRIM_CLANG_SUPPRESS_WARNING_PUSH
+    #define ROCPRIM_CLANG_SUPPRESS_WARNING(w)
+    #define ROCPRIM_CLANG_SUPPRESS_WARNING_POP
+    #define ROCPRIM_CLANG_SUPPRESS_WARNING_WITH_PUSH(w)
+#endif // __clang__
+
+#ifdef ROCPRIM_DONT_SUPPRESS_DEPRECATIONS
+    #define ROCPRIM_DETAIL_SUPPRESS_DEPRECATION_WITH_PUSH
+    #define ROCPRIM_DETAIL_SUPPRESS_DEPRECATION_POP
+#else
+    /// \brief Disables warnings from using deprecated symbols until the next
+    /// `ROCPRIM_DETAIL_SUPPRESS_DEPRECATION_POP`.
+    /// \note Track the usage of deprecated symbols in the project's issue tracker!
+    #define ROCPRIM_DETAIL_SUPPRESS_DEPRECATION_WITH_PUSH \
+        ROCPRIM_CLANG_SUPPRESS_WARNING_WITH_PUSH("-Wdeprecated-declarations")
+    #define ROCPRIM_DETAIL_SUPPRESS_DEPRECATION_POP ROCPRIM_CLANG_SUPPRESS_WARNING_POP
+#endif
+
 #endif // ROCPRIM_CONFIG_HPP_
