@@ -36,12 +36,13 @@ BEGIN_ROCPRIM_NAMESPACE
 /// \brief [DEPRECATED] Returns a number of threads in a hardware warp.
 ///
 /// It is constant for a device.
-/// This function is not supported for the gfx1030 architecture and will be removed in a future release.
+/// This function is not supported for gfx1030 and newer architectures and will be removed in a future release.
 /// Please use the new host_warp_size() and device_warp_size() functions.
-ROCPRIM_HOST_DEVICE inline
-constexpr unsigned int warp_size()
+[[deprecated("Use host_warp_size() or device_warp_size() "
+             "instead.")]] ROCPRIM_HOST_DEVICE inline constexpr unsigned int
+    warp_size()
 {
-    return warpSize;
+    return ROCPRIM_WAVEFRONT_SIZE;
 }
 
 /// \brief Returns a number of threads in a hardware warp for the actual target.
@@ -51,7 +52,7 @@ constexpr unsigned int warp_size()
 ROCPRIM_DEVICE ROCPRIM_INLINE
 constexpr unsigned int device_warp_size()
 {
-    return warpSize;
+    return ROCPRIM_WAVEFRONT_SIZE;
 }
 
 /// \brief Returns flat size of a multidimensional block (tile).
@@ -74,12 +75,7 @@ unsigned int flat_tile_size()
 ROCPRIM_DEVICE ROCPRIM_INLINE
 unsigned int lane_id()
 {
-#ifndef __HIP_CPU_RT__
     return ::__lane_id();
-#else
-    using namespace hip::detail;
-    return id(Fiber::this_fiber()) % warpSize;
-#endif
 }
 
 /// \brief Returns flat (linear, 1D) thread identifier in a multidimensional block (tile).
@@ -341,13 +337,6 @@ namespace detail
     void memory_fence_device()
     {
         ::__threadfence();
-        // Hotfix: On GFX10 (Navi 10/RDNA1, Navi 20/RDNA2) ISA and GFX11 ISA (Navi 30 GPUs),
-        // the compiler emits the L0 and L1 invalidate in the wrong order.
-        //
-        // See: https://github.com/llvm/llvm-project/pull/81450
-#if defined(__GFX10__) || defined(__GFX11__)
-        asm volatile("buffer_gl0_inv");
-#endif
     }
 }
 
