@@ -24,8 +24,8 @@
 #include <type_traits>
 
 #include "../config.hpp"
-    #include "../detail/various.hpp"
-    #include "thread.hpp"
+#include "../detail/various.hpp"
+#include "thread.hpp"
 
 /// \addtogroup warpmodule
 /// @{
@@ -67,18 +67,10 @@ warp_shuffle_op(const T& input, ShuffleOp&& op)
     for(int i = 0; i < words_no; i++)
     {
         const size_t s = std::min(sizeof(int), sizeof(T) - i * sizeof(int));
-        int word;
-#ifdef __HIP_CPU_RT__
-        std::memcpy(&word, reinterpret_cast<const char*>(&input) + i * sizeof(int), s);
-#else
+        int          word;
         __builtin_memcpy(&word, reinterpret_cast<const char*>(&input) + i * sizeof(int), s);
-#endif
         word = op(word);
-#ifdef __HIP_CPU_RT__
-        std::memcpy(reinterpret_cast<char*>(&output) + i * sizeof(int), &word, s);
-#else
         __builtin_memcpy(reinterpret_cast<char*>(&output) + i * sizeof(int), &word, s);
-#endif
     }
 
     return output;
@@ -99,13 +91,8 @@ T warp_move_dpp(const T& input)
             //       __builtin_amdgcn_update_dpp, hence fail to parse the template altogether. (Except MSVC
             //       because even using /permissive- they somehow still do delayed parsing of the body of
             //       function templates, even though they pinky-swear they don't.)
-#if !defined(__HIP_CPU_RT__)
             return ::__builtin_amdgcn_mov_dpp(v, dpp_ctrl, row_mask, bank_mask, bound_ctrl);
-#else
-            return v;
-#endif
-        }
-    );
+        });
 }
 
 /// \brief Swizzle for any data type.
@@ -304,9 +291,44 @@ ROCPRIM_DEVICE ROCPRIM_INLINE T warp_permute(const T&  input,
         { return __builtin_amdgcn_ds_permute(index, v); });
 }
 
-END_ROCPRIM_NAMESPACE
+/// \brief Broadcast the first lane to all threads.
+///
+/// Each thread in the warp obtains \p input from the first active thread in a warp.
+/// This function always operates on all <tt>device_warp_size()</tt> threads in the warp.
+///
+/// \remark This operation is significantly faster than \p warp_shuffle.
+///
+/// \param input - the value to broadcast
+template<typename T>
+ROCPRIM_DEVICE ROCPRIM_INLINE T warp_readfirstlane(const T& input)
+{
+    return detail::warp_shuffle_op(input,
+                                   [](int v) -> int { return __builtin_amdgcn_readfirstlane(v); });
+}
 
-#endif // ROCPRIM_INTRINSICS_WARP_SHUFFLE_HPP_
+/// \brief Broadcast a particular lane to all threads.
+///
+/// Each thread in the warp obtains \p input from the <tt>src_lane</tt>-th thread
+/// in the warp. \p src_lane must be the same value for all threads in the warp.
+/// This function does not distinguish between active threads and non-active
+/// threads: all threads must participate in the broadcast. This function also
+/// always operates on all <tt>device_warp_size()</tt> threads in the warp.
+///
+/// \remark This operation is significantly faster than \p warp_shuffle.
+///
+/// \param input - the value to broadcast
+/// \param src_lane - the lane whose value to broadcast to other threads in the warp
+template<typename T>
+ROCPRIM_DEVICE ROCPRIM_INLINE T warp_readlane(const T& input, const int src_lane)
+{
+    return detail::warp_shuffle_op(input,
+                                   [=](int v) -> int
+                                   { return __builtin_amdgcn_readlane(v, src_lane); });
+}
+
+END_ROCPRIM_NAMESPACE
 
 /// @}
 // end of group warpmodule
+
+#endif // ROCPRIM_INTRINSICS_WARP_SHUFFLE_HPP_
